import os
from setuptools import setup
from elisa.core.utils.dist import find_packages, TrialTest, Clean

packages, package_dir = find_packages(os.path.dirname(__file__))
cmdclass = dict(test=TrialTest, clean=Clean)

setup(name='elisa-plugin-gnome',
    version='0.1', 
    description='GNOME desktop integration services',
    long_description='GNOME desktop integration services',
    license='MIT', 
    author='Benjamin Kampmann',
    author_email='big.master.ben@web.de',
    keywords='',
    namespace_packages=['elisa', 'elisa.plugins'],
    packages=packages,
    package_dir=package_dir,
    package_data={'': ['*.png', '*.mo', '*.po']},
    entry_points="""\
    [elisa.core.components.service_provider]
    GnomeScreensaverService = elisa.plugins.gnome.gnome_screensaver_service:GnomeScreensaverService
    """,
    cmdclass=cmdclass)
